Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender-addons.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'mesh_extra_tools/mesh_select_tools/mesh_select_by_edge_length.py')
-rw-r--r--mesh_extra_tools/mesh_select_tools/mesh_select_by_edge_length.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/mesh_extra_tools/mesh_select_tools/mesh_select_by_edge_length.py b/mesh_extra_tools/mesh_select_tools/mesh_select_by_edge_length.py
index b77f9750..3ae489d5 100644
--- a/mesh_extra_tools/mesh_select_tools/mesh_select_by_edge_length.py
+++ b/mesh_extra_tools/mesh_select_tools/mesh_select_by_edge_length.py
@@ -129,7 +129,7 @@ class Select_by_edge_length():
bpy.ops.object.mode_set(mode='EDIT')
# Get the lenght of an edge, by giving this function all verts (2) in the edge
def getEdgeLength(self, verts):
vec1 = self.ob.data.vertices[verts[0]].co
@@ -199,7 +199,7 @@ class Select_init(bpy.types.Operator):
edgeSize = EnumProperty(
items=sizes,
name="Edge comparison",
- description="Choose the relation to set edge lenght",
+ description="Choose the relation to set edge length",
default='EQUAL'
)
extend = BoolProperty(
@@ -129,7 +129,7 @@ class Select_by_edge_length():
bpy.ops.object.mode_set(mode='EDIT')
- # Get the lenght of an edge, by giving this function all verts (2) in the edge
+ # Get the length of an edge, by giving this function all verts (2) in the edge
def getEdgeLength(self, verts):
vec1 = self.ob.data.vertices[verts[0]].co